package com.ruoyi.web.controller.api.family;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;

import java.io.IOException;
import java.util.Date;
import java.util.List;
import java.util.Arrays;

import com.ruoyi.app.family.photo.domain.TbFamilyPhoto;
import com.ruoyi.app.family.photo.service.ITbFamilyPhotoService;
import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.common.utils.ServletUtils;
import com.ruoyi.framework.web.service.TokenService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.ruoyi.common.utils.StringUtils;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 家族相簿照片
 * 
 * @author luobo
 * @date 2020-10-14
 */
@Api(value = "家族相簿照片", tags = "家族相簿照片")
@RequiredArgsConstructor(onConstructor_ = @Autowired)
@RestController
@RequestMapping("/system/family/photo" )
public class TbFamilyPhotoController extends BaseController {

    private final ITbFamilyPhotoService iTbFamilyPhotoService;

    @Autowired
    private TokenService tokenService;

    /**
     * 查询家族相簿照片列表
     */
    @ApiOperation("查询家族相簿照片列表")
    @PreAuthorize("@ss.hasPermi('system:familyPhoto:list')")
    @GetMapping("/list")
    public TableDataInfo list(TbFamilyPhoto tbFamilyPhoto)
    {
        startPage();
        LambdaQueryWrapper<TbFamilyPhoto> lqw = new LambdaQueryWrapper<TbFamilyPhoto>();
        if (tbFamilyPhoto.getFamilyId() != null){
            lqw.eq(TbFamilyPhoto::getFamilyId ,tbFamilyPhoto.getFamilyId());
        }
        if (tbFamilyPhoto.getAlbumId() != null){
            lqw.eq(TbFamilyPhoto::getAlbumId ,tbFamilyPhoto.getAlbumId());
        }
        if (StringUtils.isNotBlank(tbFamilyPhoto.getTitle())){
            lqw.eq(TbFamilyPhoto::getTitle ,tbFamilyPhoto.getTitle());
        }
        if (StringUtils.isNotBlank(tbFamilyPhoto.getUrl())){
            lqw.eq(TbFamilyPhoto::getUrl ,tbFamilyPhoto.getUrl());
        }
        if (StringUtils.isNotBlank(tbFamilyPhoto.getStatus())){
            lqw.eq(TbFamilyPhoto::getStatus ,tbFamilyPhoto.getStatus());
        }
        List<TbFamilyPhoto> list = iTbFamilyPhotoService.list(lqw);
        return getDataTable(list);
    }

    /**
     * 导出家族相簿照片列表
     */
    @ApiOperation("导出家族相簿照片列表")
    @PreAuthorize("@ss.hasPermi('system:familyPhoto:export')" )
    @Log(title = "家族相簿照片" , businessType = BusinessType.EXPORT)
    @GetMapping("/export" )
    public AjaxResult export(TbFamilyPhoto tbFamilyPhoto) {
        LambdaQueryWrapper<TbFamilyPhoto> lqw = new LambdaQueryWrapper<TbFamilyPhoto>(tbFamilyPhoto);
        List<TbFamilyPhoto> list = iTbFamilyPhotoService.list(lqw);
        ExcelUtil<TbFamilyPhoto> util = new ExcelUtil<TbFamilyPhoto>(TbFamilyPhoto. class);
        return util.exportExcel(list, "familyPhoto" );
    }

    /**
     * 获取家族相簿照片详细信息
     */
    @ApiOperation("获取家族相簿照片详细信息")
    @PreAuthorize("@ss.hasPermi('system:familyPhoto:query')" )
    @GetMapping(value = "/{id}" )
    public AjaxResult getInfo(@PathVariable("id" ) Long id) {
        return AjaxResult.success(iTbFamilyPhotoService.getById(id));
    }

    /**
     * 新增家族相簿照片
     */
    @ApiOperation("新增家族相簿照片")
    @PreAuthorize("@ss.hasPermi('system:familyPhoto:add')" )
    @Log(title = "家族相簿照片" , businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TbFamilyPhoto tbFamilyPhoto) {
        LoginUser loginUser = tokenService.getLoginUser(ServletUtils.getRequest());
        Long userId = loginUser.getUser().getUserId();
        tbFamilyPhoto.setCreateBy(userId);
        tbFamilyPhoto.setCreateTime(new Date());
        return toAjax(iTbFamilyPhotoService.save(tbFamilyPhoto) ? 1 : 0);
    }

    /**
     * 修改家族相簿照片
     */
    @ApiOperation("修改家族相簿照片")
    @PreAuthorize("@ss.hasPermi('system:familyPhoto:edit')" )
    @Log(title = "家族相簿照片" , businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TbFamilyPhoto tbFamilyPhoto) {
        LoginUser loginUser = tokenService.getLoginUser(ServletUtils.getRequest());
        Long userId = loginUser.getUser().getUserId();
        tbFamilyPhoto.setUpdateBy(userId);
        tbFamilyPhoto.setUpdateTime(new Date());
        return toAjax(iTbFamilyPhotoService.updateById(tbFamilyPhoto) ? 1 : 0);
    }

    /**
     * 删除家族相簿照片
     */
    @ApiOperation("删除家族相簿照片")
    @PreAuthorize("@ss.hasPermi('system:familyPhoto:remove')" )
    @Log(title = "家族相簿照片" , businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}" )
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(iTbFamilyPhotoService.removeByIds(Arrays.asList(ids)) ? 1 : 0);
    }

    /**
     * 批量上传图片
     * @return
     */
    @ApiOperation("批量上传家族相簿照片")
    @PreAuthorize("@ss.hasPermi('system:familyPhoto:upload')" )
    @Log(title = "家族相簿照片" , businessType = BusinessType.DELETE)
    @DeleteMapping("/batchUpload/{albumId}" )
    public AjaxResult batchUpload(@PathVariable Long albumId, MultipartFile[] files, String modName) throws IOException {
        LoginUser loginUser = tokenService.getLoginUser(ServletUtils.getRequest());
        Long userId = loginUser.getUser().getUserId();
        iTbFamilyPhotoService.batchUpload(userId,albumId,files,modName);
        return AjaxResult.success();
    }




}
